@@ -12,7 +12,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from kolla_ansible.version import version_info as kolla_version
 import os
 import sys
 
@@ -41,16 +40,6 @@ master_doc = 'index'
 project = u'kolla-ansible'
 copyright = u'2013, OpenStack Foundation'
 
-# The version info for the project you're documenting, acts as replacement for
-# |version| and |release|, also used in various other places throughout the
-# built documents.
-#
-# The short X.Y version.
-# The full version, including alpha/beta/rc tags.
-release = kolla_version.version_string_with_vcs()
-# The short X.Y version.
-version = kolla_version.canonical_version_string()
-
 # If true, '()' will be appended to :func: etc. cross-reference text.
 add_function_parentheses = True
 
@@ -76,9 +65,6 @@ html_theme_options = {
 # Output file base name for HTML help builder.
 htmlhelp_basename = '%sdoc' % project
 
-# Must set this variable to include year, month, day, hours, and minutes.
-html_last_updated_fmt = '%Y-%m-%d %H:%M'
-
 # Grouping the document tree into LaTeX files. List of tuples
 # (source start file, target name, title, author, documentclass
 # [howto/manual]).
@@ -93,9 +79,10 @@ latex_documents = [
 latex_use_xindy = False
 
 # openstackdocstheme options
-repository_name = 'openstack/kolla-ansible'
-bug_project = 'kolla-ansible'
-bug_tag = ''
+openstackdocs_repo_name = 'openstack/kolla-ansible'
+openstackdocs_pdf_link = True
+openstackdocs_bug_project = 'kolla-ansible'
+openstackdocs_bug_tag = ''
 openstack_projects = [
     'bifrost',
     'cinder',
@@ -112,6 +99,7 @@ openstack_projects = [
     'neutron',
     'nova',
     'octavia',
+    'oslo.messaging',
     'oslotest',
     'swift',
     'watcher',
